@@ -29,10 +29,6 @@
 #include "DebugActivities.h"
 #include "activitiesadaptor.h"
 #include "common/dbus/common.h"
-#include "ksmserver/KSMServer.h"
-
-// Private
-#define ACTIVITY_MANAGER_CONFIG_FILE_NAME QStringLiteral("kactivitymanagerdrc")
 
 namespace
 {
@@ -52,31 +48,9 @@ Activities::Private::Private(Activities *parent)
     //     << config.locationType()
     //     << QStandardPaths::standardLocations(config.locationType())
     //     ;
-
-    // Reading activities from the config file.
-    // Saving only the running activities means that if we have any
-    // errors in the config, we might end up with all activities
-    // stopped
-
-    const auto defaultState = !mainConfig().hasKey("runningActivities") ? Activities::Running
-        : !mainConfig().hasKey("stoppedActivities")                     ? Activities::Stopped
-                                                                        : Activities::Running;
-
-    const auto runningActivities = mainConfig().readEntry("runningActivities", QStringList());
-    const auto stoppedActivities = mainConfig().readEntry("stoppedActivities", QStringList());
-
-    // Do we have a running activity?
-    bool atLeastOneRunning = false;
-
-    const auto activtiesList = activityNameConfig().keyList();
-    for (const auto &activity : activtiesList) {
-        auto state = runningActivities.contains(activity) ? Activities::Running : stoppedActivities.contains(activity) ? Activities::Stopped : defaultState;
-
-        activities[activity] = state;
-
-        if (state == Activities::Running) {
-            atLeastOneRunning = true;
-        }
+    const auto activityList = activityNameConfig().keyList();
+    for (const auto &activity : activityList) {
+        activities.insert(activity);
     }
 
     // Is this our first start?
@@ -89,25 +63,18 @@ Activities::Private::Private(Activities *parent)
         for (const auto &name : names) {
             QMetaObject::invokeMethod(q, "AddActivity", Qt::QueuedConnection, Q_ARG(QString, name));
         }
-
-    } else if (!atLeastOneRunning) {
-        // If we have no running activities, but we have activities,
-        // we are in a problem. This should not happen unless the
-        // configuration file is in a big problem and told us there
-        // are no running activities, and enlists all of them as stopped.
-        // In that case, we will pretend all of them are running
-        qCWarning(KAMD_LOG_ACTIVITIES) << "The config file enlisted all activities as stopped";
-        for (auto activityKey = activities.keyBegin(); activityKey != activities.keyEnd(); ++activityKey) {
-            activities[*activityKey] = Activities::Running;
-        }
     }
+
+    // clean up no longer used config
+    mainConfig().deleteEntry("runningActivities");
+    mainConfig().deleteEntry("stoppedActivities");
 }
 
 void Activities::Private::updateSortedActivityList()
 {
     QList<ActivityInfo> a;
-    for (auto activityKey = activities.keyBegin(); activityKey != activities.keyEnd(); ++activityKey) {
-        a.append(q->ActivityInformation(*activityKey));
+    for (auto activity : std::as_const(activities)) {
+        a.append(q->ActivityInformation(activity));
     }
 
     std::sort(a.begin(), a.end(), &nameBasedOrdering);
@@ -123,7 +90,7 @@ void Activities::Private::loadLastActivity()
     // If there are no public activities, try to load the last used activity
     const auto lastUsedActivity = mainConfig().readEntry("currentActivity", QString());
 
-    setCurrentActivity((lastUsedActivity.isEmpty() && activities.size() > 0) ? activities.constBegin().key() : lastUsedActivity);
+    setCurrentActivity((lastUsedActivity.isEmpty() && activities.size() > 0) ? *activities.constBegin() : lastUsedActivity);
 }
 
 Activities::Private::~Private()
@@ -155,9 +122,6 @@ bool Activities::Private::setCurrentActivity(const QString &activity)
         }
     }
 
-    // Start activity
-    q->StartActivity(activity);
-
     // Saving the current activity, and notifying
     // clients of the change
     currentActivity = activity;
@@ -173,7 +137,7 @@ bool Activities::Private::setCurrentActivity(const QString &activity)
 
 bool Activities::Private::previousActivity()
 {
-    const auto a = q->ListActivities(Activities::Running);
+    const auto a = q->ListActivities();
 
     for (int i = 0; i < a.count(); ++i) {
         if (a[i] == currentActivity) {
@@ -186,7 +150,7 @@ bool Activities::Private::previousActivity()
 
 bool Activities::Private::nextActivity()
 {
-    const auto a = q->ListActivities(Activities::Running);
+    const auto a = q->ListActivities();
 
     for (int i = 0; i < a.count(); ++i) {
         if (a[i] == currentActivity) {
@@ -219,12 +183,10 @@ QString Activities::Private::addActivity(const QString &name)
 
         // Saves the activity info to the config
 
-        activities[activity] = Invalid;
+        activities << activity;
         activitiesCount = activities.size();
     }
 
-    setActivityState(activity, Running);
-
     q->SetActivityName(activity, name);
 
     updateSortedActivityList();
@@ -258,13 +220,6 @@ void Activities::Private::removeActivity(const QString &activity)
         }
     }
 
-    // If the activity is running, stash it
-    q->StopActivity(activity);
-
-    setActivityState(activity, Activities::Invalid);
-
-    bool currentActivityDeleted = false;
-
     {
         QWriteLocker lock(&activitiesLock);
         // Removing the activity
@@ -276,20 +231,12 @@ void Activities::Private::removeActivity(const QString &activity)
                 break;
             }
         }
-
-        // If the removed activity was the current one,
-        // set another activity as current
-        currentActivityDeleted = (currentActivity == activity);
     }
 
     activityNameConfig().deleteEntry(activity);
     activityDescriptionConfig().deleteEntry(activity);
     activityIconConfig().deleteEntry(activity);
 
-    if (currentActivityDeleted) {
-        ensureCurrentActivityIsRunning();
-    }
-
     Q_EMIT q->ActivityRemoved(activity);
 
     QMetaObject::invokeMethod(q, "ActivityRemoved", Qt::QueuedConnection, Q_ARG(QString, activity));
@@ -322,94 +269,6 @@ void Activities::Private::configSync()
     config.sync();
 }
 
-void Activities::Private::setActivityState(const QString &activity, Activities::State state)
-{
-    bool configNeedsUpdating = false;
-
-    {
-        QWriteLocker lock(&activitiesLock);
-
-        Q_ASSERT(activities.contains(activity));
-
-        if (activities.value(activity) == state) {
-            return;
-        }
-
-        // Treating 'Starting' as 'Running', and 'Stopping' as 'Stopped'
-        // as far as the config file is concerned
-        configNeedsUpdating = ((activities[activity] & 4) != (state & 4));
-
-        activities[activity] = state;
-    }
-
-    switch (state) {
-    case Activities::Running:
-        Q_EMIT q->ActivityStarted(activity);
-        break;
-
-    case Activities::Stopped:
-        Q_EMIT q->ActivityStopped(activity);
-        break;
-
-    default:
-        break;
-    }
-
-    Q_EMIT q->ActivityStateChanged(activity, state);
-
-    if (configNeedsUpdating) {
-        QReadLocker lock(&activitiesLock);
-
-        mainConfig().writeEntry("runningActivities", activities.keys(Activities::Running) + activities.keys(Activities::Starting));
-        mainConfig().writeEntry("stoppedActivities", activities.keys(Activities::Stopped) + activities.keys(Activities::Stopping));
-        scheduleConfigSync();
-    }
-
-    updateSortedActivityList();
-}
-
-void Activities::Private::ensureCurrentActivityIsRunning()
-{
-    // If the current activity is not running,
-    // make some other activity current
-
-    const auto runningActivities = q->ListActivities(Activities::Running);
-
-    if (!runningActivities.contains(currentActivity) && runningActivities.size() > 0) {
-        setCurrentActivity(runningActivities.first());
-    }
-}
-
-void Activities::Private::activitySessionStateChanged(const QString &activity, int status)
-{
-    QString currentActivity = this->currentActivity;
-
-    {
-        QReadLocker lock(&activitiesLock);
-        if (!activities.contains(activity)) {
-            return;
-        }
-    }
-
-    switch (status) {
-    case KSMServer::Started:
-    case KSMServer::FailedToStop:
-        setActivityState(activity, Activities::Running);
-        break;
-
-    case KSMServer::Stopped:
-        setActivityState(activity, Activities::Stopped);
-
-        if (currentActivity == activity) {
-            ensureCurrentActivityIsRunning();
-        }
-
-        break;
-    }
-
-    QMetaObject::invokeMethod(this, "configSync", Qt::QueuedConnection);
-}
-
 // Main
 
 Activities::Activities(QObject *parent)
@@ -432,9 +291,6 @@ Activities::Activities(QObject *parent)
 
     d->configSyncTimer.setSingleShot(true);
 
-    d->ksmserver = new KSMServer(this);
-    d->connect(d->ksmserver, SIGNAL(activitySessionStateChanged(QString, int)), SLOT(activitySessionStateChanged(QString, int)));
-
     d->updateSortedActivityList();
     // Loading the last used activity, if possible
     d->loadLastActivity();
@@ -500,19 +356,6 @@ QStringList Activities::ListActivities() const
     return s;
 }
 
-QStringList Activities::ListActivities(int state) const
-{
-    QReadLocker lock(&d->activitiesLock);
-
-    QStringList s;
-    for (const auto &a : std::as_const(d->sortedActivities)) {
-        if (a.state == (State)state) {
-            s << a.id;
-        }
-    }
-    return s;
-}
-
 QList<ActivityInfo> Activities::ListActivitiesWithInformation() const
 {
     using namespace kamd::utils;
@@ -524,7 +367,7 @@ QList<ActivityInfo> Activities::ListActivitiesWithInformation() const
 
 ActivityInfo Activities::ActivityInformation(const QString &activity) const
 {
-    return ActivityInfo{activity, ActivityName(activity), ActivityDescription(activity), ActivityIcon(activity), ActivityState(activity)};
+    return ActivityInfo{activity, ActivityName(activity), ActivityDescription(activity), ActivityIcon(activity)};
 }
 
 #define CREATE_GETTER_AND_SETTER(What)                                                                                                                         \
@@ -556,43 +399,6 @@ CREATE_GETTER_AND_SETTER(Icon)
 
 #undef CREATE_GETTER_AND_SETTER
 
-// Main
-
-void Activities::StartActivity(const QString &activity)
-{
-    {
-        QReadLocker lock(&d->activitiesLock);
-        if (!d->activities.contains(activity) || d->activities[activity] != Stopped) {
-            return;
-        }
-    }
-
-    d->setActivityState(activity, Starting);
-    d->ksmserver->startActivitySession(activity);
-}
-
-void Activities::StopActivity(const QString &activity)
-{
-    {
-        QReadLocker lock(&d->activitiesLock);
-        if (!d->activities.contains(activity) //
-            || d->activities[activity] == Stopped //
-            || d->activities.size() == 1 //
-            || d->activities.keys(Activities::Running).size() <= 1) {
-            return;
-        }
-    }
-
-    d->setActivityState(activity, Stopping);
-    d->ksmserver->stopActivitySession(activity);
-}
-
-int Activities::ActivityState(const QString &activity) const
-{
-    QReadLocker lock(&d->activitiesLock);
-    return d->activities.contains(activity) ? d->activities[activity] : Invalid;
-}
-
 #include "moc_Activities.cpp"
 
 #include "moc_Activities_p.cpp"
