@@ -31,10 +31,6 @@ public:
     // the user has used
     void loadLastActivity();
 
-    // If the current activity is not running,
-    // make some other activity current
-    void ensureCurrentActivityIsRunning();
-
 public Q_SLOTS:
     bool setCurrentActivity(const QString &activity);
     bool previousActivity();
@@ -42,15 +38,13 @@ public Q_SLOTS:
     void updateSortedActivityList();
 
 public:
-    void setActivityState(const QString &activity, Activities::State state);
-
     QTimer configSyncTimer;
     KConfig config;
 
     // Interface to the session management
     KSMServer *ksmserver;
 
-    QHash<QString, Activities::State> activities;
+    QSet<QString> activities;
     QList<ActivityInfo> sortedActivities;
     QReadWriteLock activitiesLock;
     QString currentActivity;
@@ -101,7 +95,6 @@ public Q_SLOTS:
 
     QString addActivity(const QString &name);
     void removeActivity(const QString &activity);
-    void activitySessionStateChanged(const QString &activity, int state);
 
 private:
     Activities *const q;
