@@ -34,9 +34,9 @@ public:
     void configFileChanged(const QString &file)
     {
         if (file == pluginConfigFile) {
-            emit q->pluginConfigChanged();
+            Q_EMIT q->pluginConfigChanged();
         } else {
-            emit q->mainConfigChanged();
+            Q_EMIT q->mainConfigChanged();
         }
     }
 
@@ -58,3 +58,5 @@ Config::Config(QObject *parent)
 Config::~Config()
 {
 }
+
+#include "moc_Config.cpp"
